/***********************************************************************
 *                                                                     *
 * $Id: hpgsjs.h 571 2010-09-12 19:22:34Z hpgs $
 *                                                                     *
 * hpgs - HPGl Script, a hpgl/2 interpreter, which uses a Postscript   *
 *        API for rendering a scene and thus renders to a variety of   *
 *        devices and fileformats.                                     *
 *                                                                     *
 * (C) 2005 EV-i Informationstechnologie GmbH   http://www.ev-i.at     *
 *                                                                     *
 * Author: Wolfgang Glas                                               *
 *                                                                     *
 *  hpgs is free software; you can redistribute it and/or              *
 * modify it under the terms of the GNU Lesser General Public          *
 * License as published by the Free Software Foundation; either        *
 * version 2.1 of the License, or (at your option) any later version.  *
 *                                                                     *
 * hpgs is distributed in the hope that it will be useful,             *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of      *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU   *
 * Lesser General Public License for more details.                     *
 *                                                                     *
 * You should have received a copy of the GNU Lesser General Public    *
 * License along with this library; if not, write to the               *
 * Free Software  Foundation, Inc., 59 Temple Place, Suite 330,        *
 * Boston, MA  02111-1307  USA                                         *
 *                                                                     *
 ***********************************************************************
 *                                                                     *
 * The private interfaces for the js/canvas device                     *
 *                                                                     *
 ***********************************************************************/

#ifndef	__HPGS_JS_H
#define	__HPGS_JS_H

#include<hpgs.h>

#ifndef __GNUC__
#ifdef _MSC_VER
#define __inline__ __inline
#else
#define __inline__ inline
#endif
#endif

/* All this is needed in order to set the right attributes for functions.
   This allows us to build fully compliant dlls under Windows and to
   hide functions needed for the implementation of the API in
   ELF modules. Additionally, we make use of the 'format' attribute of
   gcc in order to get the most out of -Wall.
 */
#ifdef WIN32
# ifdef __GNUC__
#  ifdef BUILD_hpgsjs_DLL
#   define HPGS_JS_API __attribute__((dllexport))
#   define HPGS_JS_I18N_API __attribute__((dllexport,format_arg (1)))
#   define HPGS_JS_I18N_N_API __attribute__((dllexport,format_arg (1),format_arg (2)))
#  else
#   define HPGS_JS_API __attribute__((dllimport))
#   define HPGS_JS_I18N_API __attribute__((dllimport,format_arg (1)))
#   define HPGS_JS_I18N_N_API __attribute__((dllimport,format_arg (1),format_arg (2)))
#  endif
# else
#  ifdef HPGS_JS_BUILD_SLIB
#   define HPGS_JS_API __declspec(dllexport)
#  else
#   define HPGS_JS_API __declspec(dllimport)
#  endif
# endif
#else
# ifdef __GNUC__
#  define HPGS_JS_I18N_API __attribute__((format_arg (1)))
#  define HPGS_JS_I18N_N_API __attribute__((format_arg (1),format_arg (2)))
# endif
#endif

#ifndef HPGS_JS_API
#define HPGS_JS_API
#endif
#ifndef HPGS_JS_I18N_API
#define HPGS_JS_I18N_API HPGS_JS_API
#endif
#ifndef HPGS_JS_I18N_N_API
#define HPGS_JS_I18N_N_API HPGS_JS_API
#endif

#ifdef __cplusplus
extern "C" {
#endif

/*! \file hpgsjs.h

   \brief The public interfaces for the JavaScript/canvas device.

   A header file, which declares the public functions used by the SWFjs
   rendering device.
*/
#define HPGS_JS_MAJOR_VERSION 1
#define HPGS_JS_MINOR_VERSION 1
#define HPGS_JS_PATCH_VERSION 0
#define HPGS_JS_EXTRA_VERSION -pre

// a string for displaying the version.
#define HPGS_JS_VERSION HPGS_STRINGIFY(HPGS_JS_MAJOR_VERSION) "." HPGS_STRINGIFY(HPGS_JS_MINOR_VERSION) "." HPGS_STRINGIFY(HPGS_JS_PATCH_VERSION) HPGS_STRINGIFY(HPGS_JS_EXTRA_VERSION)

HPGS_JS_API void hpgs_js_init();

HPGS_JS_I18N_API const char *hpgs_js_i18n(const char *msg);
HPGS_JS_I18N_N_API const char *hpgs_js_i18n_n(const char *msg,
                                                const char *msg_plural,
                                                unsigned long n);

HPGS_JS_API hpgs_device *hpgs_new_js_device(const char *filename,
                                                   const hpgs_bbox *bb,
                                                   double x_res, double y_res,
                                                   hpgs_bool do_rop3);

#ifdef __cplusplus
} // end of extern "C"
#endif

#endif /* ! __HPGS_JS_H */
